Buy Head and Shoulders Men Full & Thick Dandruff 2-in-1 Shampoo 420 mL Online in Canada | FREE Ship $29+
Description: Head and Shoulders Men Full & Thick Dandruff 2-in-1 Shampoo - Get fuller, thicker looking hair* and stay at the top of your game with Head &amp; Shoulders Full &a
Keywords: Head and Shoulders Men Full & Thick Dandruff 2-in-1 Shampoo, Medicine & Health, Personal Care, Vitamins & Supplements, Beauty & Skin Care, Baby & Kids, Diet & Fitness, Green & Natural, House & Home, Gift Cards, Samples, Promotions, Food & Snacks, Gender Based Samples, One Time Samples, Brands, Ostomy, Canada, Canadian

## Stay in the loop!

Be the first to hear about exclusive offers and new arrivals
from these great brands and more!

## Stay in the loop!

Be the first to hear about exclusive offers and new arrivals
from these great brands and more!

Head and Shoulders Men Full & Thick Dandruff 2-in-1 Shampoo Get fuller, thicker looking hair* and stay at the top of your game with Head & Shoulders Full & Thick Dandruff 2-in-1 Shampoo. Full & Thick 2-in-1 cleans to restore fullness to thin looking hair from the first wash.
With its Fresh Scent Technology, proven dandruff-fighting formula and conditioning power, you’ll be well on your way to fuller, thicker-looking*, awesome-looking hair. Use with Full & Thick Advanced Thickening Tonic. Now that’s game changing!
*bulk fullness; Full & Thick 2-in-1 vs. dirty/unwashed hair
Features:

- Cleans to restore fullness to thin looking hair from the first wash
- Formulated with Head & Shoulders’ Fresh Scent Technology for an improved in-shower scent experience
- Dandruff 2-in-1 shampoo that delivers clean, handsome hair

Application: Shake before use. Wet hair. Massage onto scalp. Leave on for several minutes. Rinse. Repeat, if desired. Use at least twice a week or as directed by a doctor.
Ingredients: Water, Sodium Lauryl Sulfate, Sodium Laureth Sulfate, Glycol Distearate, Zinc Carbonate, Sodium Chloride, Sodium Xylenesulfonate, Dimethicone, Cocamidopropyl Betaine, Fragrance, Sodium Benzoate, Guar Hydroxypropyltrimonium Chloride, Magnesium Carbonate Hydroxide, Tocopheryl Acetate, Methylchloroisothiazolinone, Methylisothiazolinone, Yellow 5, Blue 1
For external use only. Avoid contact with eyes. If contact occurs, rinse thoroughly with water. Discontinue use if eye irritation occurs. If condition worsens or does not improve after regular use of this product, consult a doctor. Keep out of reach of children.
Head & Shoulders
7.64CAD
00037000880714
Personal Care Gentlemen's Grooming Hair Care Shampoo & Conditioner
Head and Shoulders Men Full & Thick Dandruff 2-in-1 Shampoo
No reviews yet

# Head and Shoulders Men Full & Thick Dandruff 2-in-1 Shampoo

420 mL
No reviews yet
$8.49
$7.64

Quantity:
-
+
Log in to add this to your Wish List

### Description & Features

Get fuller, thicker looking hair* and stay at the top of your game with Head & Shoulders Full & Thick Dandruff 2-in-1 Shampoo. Full & Thick 2-in-1 cleans to restore fullness to thin looking hair from the first wash.
With its Fresh Scent Technology, proven dandruff-fighting formula and conditioning power, you’ll be well on your way to fuller, thicker-looking*, awesome-looking hair. Use with Full & Thick Advanced Thickening Tonic. Now that’s game changing!
*bulk fullness; Full & Thick 2-in-1 vs. dirty/unwashed hair
Features:

- Cleans to restore fullness to thin looking hair from the first wash
- Formulated with Head & Shoulders’ Fresh Scent Technology for an improved in-shower scent experience
- Dandruff 2-in-1 shampoo that delivers clean, handsome hair

Application: Shake before use. Wet hair. Massage onto scalp. Leave on for several minutes. Rinse. Repeat, if desired. Use at least twice a week or as directed by a doctor.
Ingredients: Water, Sodium Lauryl Sulfate, Sodium Laureth Sulfate, Glycol Distearate, Zinc Carbonate, Sodium Chloride, Sodium Xylenesulfonate, Dimethicone, Cocamidopropyl Betaine, Fragrance, Sodium Benzoate, Guar Hydroxypropyltrimonium Chloride, Magnesium Carbonate Hydroxide, Tocopheryl Acetate, Methylchloroisothiazolinone, Methylisothiazolinone, Yellow 5, Blue 1
For external use only. Avoid contact with eyes. If contact occurs, rinse thoroughly with water. Discontinue use if eye irritation occurs. If condition worsens or does not improve after regular use of this product, consult a doctor. Keep out of reach of children.
No Information Provided
Similar Hair Care

### Similar Hair Care

next Prev
Add to Cart +
Nutricap Shampoo
$7.99$7.19
Add to Cart +
Aubrey Men's Stock Ginseng Biotin Shampoo
$14.49$11.59
Add to Cart +
Old Spice High Endurance Hair & Body Wash
$6.49$5.51
Add to Cart +
Herbal Glo Nutrient Conditioner
$15.99$13.59
Add to Cart +
Nivea Men Active3 Sport Shower Gel
$5.99$5.39
Add to Cart +
Dove Men +Care Deep Clean Shampoo + Conditioner
$7.99$6.79
Add to Cart +
Dove Men +Care Thick & Clean Shampoo
$7.99$7.19
Add to Cart +
Dove Men +Care Anti Dandruff Shampoo
$7.99$6.79
Add to Cart +
L'Oreal Men Thickening Shampoo
$7.99$6.79
Add to Cart +
Kiss My Face Natural Man 3 in 1 Wash
$7.99$6.39
Add to Cart +
Axe Just Clean Shampoo
$6.49$5.84
Add to Cart +
Head & Shoulders with Old Spice 2-In-1
$8.49$7.64
View ALL
Other Head & Shoulders Products

### Other Head & Shoulders Products

next Prev
Add to Cart +
Head & Shoulders Classic Clean 2-in-1
$7.99
Add to Cart +
Head & Shoulders Clinical Strength Shampoo
$7.99
Add to Cart +
Head & Shoulders Classic Clean Shampoo
$12.99
Add to Cart +
Head & Shoulders Classic Clean Shampoo
$7.99
Add to Cart +
Head & Shoulders Dry Scalp Care 2-in-1
$7.99
Add to Cart +
Head & Shoulders Smooth & Silky 2-in-1
$7.99
Add to Cart +
Head & Shoulders Dry Scalp Care Shampoo
$7.99
Add to Cart +
Head & Shoulders Green Apple 2-in-1 Shampoo & Conditioner
$7.99
Add to Cart +
Head & Shoulders For Men 2-in-1 Refresh
$7.99
Add to Cart +
Head & Shoulders Green Apple Shampoo
$7.99
Add to Cart +
Head & Shoulders For Men Active Sport 2-in-1
$7.99
Add to Cart +
Head & Shoulders For Men Refresh Shampoo
$7.99
Customer Reviews
No reviews so far
There have been no reviews so far... Be the first to leave a review!
Write a Review
First Name
Email (not published)
YouTube Video (Optional. Eg: https://www.youtube.com/watch?v=xxxxxxxxxxx)
Rating
0 1 2 3 4 5
What is 1 plus 1 (1+1=?)
Write a Review